## ImageGenie

* Training a model to classify between different classes is tough. 
* This single package lets us harness the power of the state of the art models without any hassle of
  coding them ourselves.
* Just 3 lines of code and we're done.

### Installation

```
pip install imageGenie
```